seshypy package
===============

Submodules
----------

seshypy\.base\_session module
-----------------------------

.. automodule:: seshypy.base_session
    :members:
    :undoc-members:
    :show-inheritance:

seshypy\.session module
-----------------------

.. automodule:: seshypy.session
    :members:
    :undoc-members:
    :show-inheritance:

seshypy\.utils module
---------------------

.. automodule:: seshypy.utils
    :members:
    :undoc-members:
    :show-inheritance:

seshypy\.version module
-----------------------

.. automodule:: seshypy.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: seshypy
    :members:
    :undoc-members:
    :show-inheritance:
